==> kafka-secret-registry-7.5.7-sources.jar: io/confluent/kafka/secretregistry/storage/SecretKey.java <==
/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Confluent Community License (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of the
 * License at
 *
 * http://www.confluent.io/confluent-community-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

package io.confluent.kafka.secretregistry.storage;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;

import java.util.Objects;

import javax.validation.constraints.Min;

import org.hibernate.validator.constraints.NotEmpty;

@JsonPropertyOrder(value = {"keytype", "path", "version", "magic"})
public class SecretKey extends SecretRegistryKey {

  public static final String MAX_KEY = "__max_key__";
  public static final String MIN_KEY = "__min_key__";

  private static final int MAGIC_BYTE = 1;
  @NotEmpty
  private String path;
  @NotEmpty
  private String key;
  @Min(1)
  @NotEmpty
  private Integer version;

  public SecretKey(
      @JsonProperty("path") String path,
      @JsonProperty("key") String key,
      @JsonProperty("version") int version
  ) {
    super(SecretRegistryKeyType.SECRET);
    this.magicByte = MAGIC_BYTE;
    this.path = path;
    this.key = key;
    this.version = version;
  }

  @JsonProperty("path")
  public String getPath() {
    return this.path;
  }

  @JsonProperty("path")
  public void setPath(String path) {
    this.path = path;
  }

  @JsonProperty("key")
  public String getKey() {
    return this.key;
  }

  @JsonProperty("key")
  public void setKey(String key) {
    this.key = key;
  }

  @JsonProperty("version")
  public int getVersion() {
    return this.version;
  }

  @JsonProperty("version")
  public void setVersion(int version) {
    this.version = version;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    if (!super.equals(o)) {
      return false;
    }
    SecretKey secretKey = (SecretKey) o;
    return Objects.equals(path, secretKey.path)
        && Objects.equals(key, secretKey.key)
        && Objects.equals(version, secretKey.version);
  }

  @Override
  public int hashCode() {
    return Objects.hash(super.hashCode(), path, key, version);
  }

  @Override
  public String toString() {
    return "SecretKey{"
        + "path='" + path + '\''
        + ", key='" + key + '\''
        + ", version=" + version
        + '}';
  }

  @Override
  public int compareTo(SecretRegistryKey o) {
    int compare = super.compareTo(o);
    if (compare == 0) {
      return compareTo((SecretKey) o);
    } else {
      return compare;
    }
  }

  public int compareTo(SecretKey that) {
    if (this.path.compareTo(that.path) < 0) {
      return -1;
    } else if (this.path.compareTo(that.path) > 0) {
      return 1;
    }

    if (compareKeys(this.key, that.key) < 0) {
      return -1;
    } else if (compareKeys(this.key, that.key) > 0) {
      return 1;
    }

    if (this.version.compareTo(that.version) < 0) {
      return -1;
    } else if (this.version.compareTo(that.version) > 0) {
      return 1;
    }
    return 0;
  }

  public static int compareKeys(String key1, String key2) {
    if (key1.equals(MIN_KEY)) {
      if (key2.equals(MIN_KEY)) {
        return 0;
      } else {
        return -1;
      }
    }

    if (key2.equals(MAX_KEY)) {
      if (key1.equals(MAX_KEY)) {
        return 0;
      } else {
        return -1;
      }
    }

    return key1.compareTo(key2);
  }
}

==> kafka-secret-registry-7.8.0-sources.jar: io/confluent/kafka/secretregistry/storage/SecretKey.java <==
/*
 * Copyright 2019 Confluent Inc.
 *
 * Licensed under the Confluent Community License (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of the
 * License at
 *
 * http://www.confluent.io/confluent-community-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

package io.confluent.kafka.secretregistry.storage;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;

import java.util.Objects;

import javax.validation.constraints.Min;

import org.hibernate.validator.constraints.NotEmpty;

@JsonPropertyOrder(value = {"keytype", "path", "version", "magic"})
public class SecretKey extends SecretRegistryKey {

  // https://confluentinc.atlassian.net/browse/CC-15667
  // Temp fix for the issue with the key comparison
  // starting min key with @ allows capital alphabets as starting character of KEY
  // using { as starting character of MAX_KEY to allow small case alphabets as starting key
  public static final String MAX_KEY = "{";

  public static final String MIN_KEY = "@";

  private static final int MAGIC_BYTE = 1;
  @NotEmpty
  private String path;
  @NotEmpty
  private String key;
  @Min(1)
  @NotEmpty
  private Integer version;

  public SecretKey(
      @JsonProperty("path") String path,
      @JsonProperty("key") String key,
      @JsonProperty("version") int version
  ) {
    super(SecretRegistryKeyType.SECRET);
    this.magicByte = MAGIC_BYTE;
    this.path = path;
    this.key = key;
    this.version = version;
  }

  @JsonProperty("path")
  public String getPath() {
    return this.path;
  }

  @JsonProperty("path")
  public void setPath(String path) {
    this.path = path;
  }

  @JsonProperty("key")
  public String getKey() {
    return this.key;
  }

  @JsonProperty("key")
  public void setKey(String key) {
    this.key = key;
  }

  @JsonProperty("version")
  public int getVersion() {
    return this.version;
  }

  @JsonProperty("version")
  public void setVersion(int version) {
    this.version = version;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    if (!super.equals(o)) {
      return false;
    }
    SecretKey secretKey = (SecretKey) o;
    return Objects.equals(path, secretKey.path)
        && Objects.equals(key, secretKey.key)
        && Objects.equals(version, secretKey.version);
  }

  @Override
  public int hashCode() {
    return Objects.hash(super.hashCode(), path, key, version);
  }

  @Override
  public String toString() {
    return "SecretKey{"
        + "path='" + path + '\''
        + ", key='" + key + '\''
        + ", version=" + version
        + '}';
  }

  @Override
  public int compareTo(SecretRegistryKey o) {
    int compare = super.compareTo(o);
    if (compare == 0) {
      return compareTo((SecretKey) o);
    } else {
      return compare;
    }
  }

  public int compareTo(SecretKey that) {
    if (this.path.compareTo(that.path) < 0) {
      return -1;
    } else if (this.path.compareTo(that.path) > 0) {
      return 1;
    }

    if (compareKeys(this.key, that.key) < 0) {
      return -1;
    } else if (compareKeys(this.key, that.key) > 0) {
      return 1;
    }

    if (this.version.compareTo(that.version) < 0) {
      return -1;
    } else if (this.version.compareTo(that.version) > 0) {
      return 1;
    }
    return 0;
  }

  public static int compareKeys(String key1, String key2) {
    if (key1.equals(MIN_KEY)) {
      if (key2.equals(MIN_KEY)) {
        return 0;
      } else {
        return -1;
      }
    }

    if (key2.equals(MAX_KEY)) {
      if (key1.equals(MAX_KEY)) {
        return 0;
      } else {
        return -1;
      }
    }

    return key1.compareTo(key2);
  }
}
